/*
 * Project name:
     DIGI POT 2 click
 * Copyright:
     (c) Mikroelektronika, 2016.
  * Revision History
     20160622 (AM);
       - initial release;
 * Description:
     This program demonstrates the usage of Digital Potentiometer 2 Board (TPL0501).
     Voltage derived from W pin is read by MCU's ADC (AN2). Scaled value is then displayed at PORTD LEDs.
     User can increase or decrease resitance by pressing buttons RB2 and RB3. It's all happening in an endless loop.
 * Test configuration:
     mcu:             PIC18F87K22
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39960b.pdf
     Dev.Board:       EasyPIC PRO v7
                      http://www.mikroe.com/eng/products/view/815/easypic-pro-v7-development-system/
     Oscillator:      HS-PLL 64.0000 MHz, 16.0000 MHz Crystal
     ext. modules:    DigiPot 2 click

     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
 * NOTES:
     - Digi Pot 2 click must be connected on mikroBUS socket 1.
     - Connect H to Vcc, L to Gnd and W to RA1 pin.
     - Don't use pull-up(down) resistor at RA1 pin.
     - Turn ON PORTD LEDs (SW6.4).
     - Place Button Press Level switch in upper position for PORTB and pull down PortB pins 2 and 3 (PortB three-state switch).
*/

#include "built_in.h"

sbit DigPot_CS at LATE0_bit;
sbit DigPot_CS_Direction at TRISE0_bit;

unsigned int adc_value;
char counter;

void InitMain() {

  ANCON0 = 0;                // Configure all port pins as digital
  ANCON1 = 0;
  ANCON2 = 0;

  TRISA = 0x02;              // Set RA1 pin as input
  TRISB = 0x0C;              // Set RB0 and RB1 as input
  TRISD = 0x00;              // Set PORTD as output

  ADC_Init();                // Initialize ADC module

  DigPot_CS = 1;
  DigPot_CS_Direction = 0;

  // Initialize SPI1 module
  SPI1_Init_Advanced(_SPI_MASTER_OSC_DIV16, _SPI_DATA_SAMPLE_MIDDLE, _SPI_CLK_IDLE_LOW, _SPI_LOW_2_HIGH);

  adc_value = 0;
  counter = 0;
}


void main() {

  InitMain();                            // Perform main initialization
  Delay_ms(100);

  while (1) {                            // Endless loop

    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPI1_Write(0);
    SPI1_Write(counter);

    SPI1_Write(0x20);
    SPI1_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip

    adc_value = ADC_Read(1);             // Get 10-bit results of AD conversion
    LATD = (unsigned char)(adc_value >> 2);

    if (RB2_bit)                         // Press RB2 to decrease resistance between W and L
      counter ++;
    if (RB3_bit)                         // Press RB3 to increase resistance between W and L
      counter --;

    Delay_ms(50);                        // Delay for debouncing

  }
}